@@ -80,76 +80,6 @@ sub test_cases
   my ($o, $query, $sSE, $sM, $file);
   my $bogus_query = $WWW::Search::Test::bogus_query;
 
-  $sSE = 'AltaVista';
-  $sM = 'John Heidemann <johnh@isi.edu>';
-
-  $file = 'zero_result_no_plus';
-  $oTest->test($sSE, $sM, $file, $bogus_query, $TEST_EXACTLY);
-
-  $file = 'zero_result';
-  $query = '+LSAM +' . $bogus_query;
-  $oTest->test($sSE, $sM, $file, $query, $TEST_EXACTLY);
-
-  $file = 'one_page_result';
-  $query = '+LS'.'AM +Aut'.'oSearch';
-  $oTest->test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 10);
-
-  $file = 'two_page_result';
-  $query = '+LS'.'AM +IS'.'I +Heide'.'mann';
-  $oTest->test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 10);
-
-  ######################################################################
-
-  $sSE = 'AltaVista::Web';
-  $sM = 'John Heidemann <johnh@isi.edu>';
-
-  $file = 'zero_result';
-  $query = '+LSA'.'M +' . $bogus_query;
-  $oTest->test($sSE, $sM, $file, $query, $TEST_EXACTLY);
-
-  $file = 'one_page_result';
-  $query = '+LSA'.'M +AutoSea'.'rch';
-  $oTest->test($sSE, $sM, $file, $query, $TEST_RANGE, 2, 10);
-
-  $file = 'two_page_result';
-  $query = '+LSA'.'M +IS'.'I +I'.'B';
-  $oTest->test($sSE, $sM, $file, $query, $TEST_GREATER_THAN, 10);
-
-  ######################################################################
-
-  $sSE = 'AltaVista::AdvancedWeb';
-  $sM = 'John Heidemann <johnh@isi.edu>';
-  $oTest->not_working($sSE, $sM);
-  # $query = 'LS'.'AM and ' . $bogus_query;
-  # $oTest->test($sSE, $sM, 'zero', $query, $TEST_EXACTLY);
-  # $query = 'LSA'.'M and AutoSea'.'rch';
-  # $oTest->test($sSE, $sM, 'one', $query, $TEST_RANGE, 2, 11);
-  # $query = 'LSA'.'M and IS'.'I and I'.'B';
-  # $oTest->test($sSE, $sM, 'two', $query, $TEST_GREATER_THAN, 10);
-
-  ######################################################################
-
-  $sSE = 'AltaVista::News';
-  $sM = 'John Heidemann <johnh@isi.edu>';
-  $oTest->not_working($sSE, $sM);
-  # $query = '+pe'.'rl +' . $bogus_query;
-  # $oTest->test($sSE, $sM, 'zero', $query, $TEST_EXACTLY);
-  # $query = '+Pe'.'rl +CP'.'AN';
-  # $oTest->test($sSE, $sM, 'multi', $query, $TEST_GREATER_THAN, 30); # 30 hits/page
-
-  ######################################################################
-
-  $sSE = 'AltaVista::AdvancedNews';
-  $sM = 'John Heidemann <johnh@isi.edu>';
-  $oTest->not_working($sSE, $sM);
-  # $query = 'per'.'l and ' . $bogus_query;
-  # $oTest->test($sSE, $sM, 'zero', $query, $TEST_EXACTLY);
-  # $query = 'Per'.'l and CP'.'AN';
-  # $oTest->test($sSE, $sM, 'multi', $query, $TEST_GREATER_THAN, 70); # 30 hits/page
-
-  ######################################################################
-
-  $oTest->eval_test('AltaVista::Intranet');
 
   ######################################################################
 
